@@ -7,7 +7,7 @@
  *
  * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
  *
- * $Id: mainwin.cc 13555 2012-10-08 04:23:39Z jordan $
+ * $Id: mainwin.cc 13750 2013-01-04 00:00:55Z jordan $
  */
 
 #include <cassert>
@@ -250,11 +250,11 @@ TrMainWindow :: TrMainWindow( Session& session, Prefs& prefs, TorrentModel& mode
     myTrayIcon.setIcon( QApplication::windowIcon( ) );
 
     connect( &myPrefs, SIGNAL(changed(int)), this, SLOT(refreshPref(int)) );
-    connect( ui.action_ShowMainWindow, SIGNAL(toggled(bool)), this, SLOT(toggleWindows(bool)));
+    connect( ui.action_ShowMainWindow, SIGNAL(triggered(bool)), this, SLOT(toggleWindows(bool)));
     connect( &myTrayIcon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
              this, SLOT(trayActivated(QSystemTrayIcon::ActivationReason)));
 
-    ui.action_ShowMainWindow->setChecked( !minimized );
+    toggleWindows( !minimized );
     ui.action_TrayIcon->setChecked( minimized || prefs.getBool( Prefs::SHOW_TRAY_ICON ) );
 
     ui.verticalLayout->addWidget( createStatusBar( ) );
@@ -312,23 +312,6 @@ TrMainWindow :: ~TrMainWindow( )
 *****
 ****/
 
-void
-TrMainWindow :: closeEvent( QCloseEvent * event )
-{
-    // if they're using a tray icon, close to the tray
-    // instead of exiting
-    if( !myPrefs.getBool( Prefs :: SHOW_TRAY_ICON ) )
-        event->accept( );
-    else {
-        toggleWindows( false );
-        event->ignore( );
-    }
-}
-
-/****
-*****
-****/
-
 void
 TrMainWindow :: onSessionSourceChanged( )
 {
@@ -566,6 +549,31 @@ TrMainWindow :: setSortAscendingPref( bool b )
 *****
 ****/
 
+void
+TrMainWindow :: showEvent( QShowEvent * event )
+{
+    Q_UNUSED (event);
+
+    ui.action_ShowMainWindow->setChecked(true);
+}
+
+/****
+*****
+****/
+
+void
+TrMainWindow :: hideEvent( QHideEvent * event )
+{
+    Q_UNUSED (event);
+
+    if (!isVisible())
+        ui.action_ShowMainWindow->setChecked(false);
+}
+
+/****
+*****
+****/
+
 void
 TrMainWindow :: onPrefsDestroyed( )
 {
@@ -993,7 +1001,7 @@ TrMainWindow :: trayActivated( QSystemTrayIcon::ActivationReason reason )
         if( isMinimized ( ) )
             toggleWindows( true );
         else
-            ui.action_ShowMainWindow->toggle( );
+            toggleWindows( !isVisible() );
     }
 }
 
@@ -1079,6 +1087,7 @@ TrMainWindow :: refreshPref( int key )
             b = myPrefs.getBool( key );
             ui.action_TrayIcon->setChecked( b );
             myTrayIcon.setVisible( b );
+            dynamic_cast<MyApp*>(QCoreApplication::instance())->setQuitOnLastWindowClosed(!b);
             refreshTrayIconSoon( );
             break;
 
